
# Slot: linkable




URI: [nwb_schema_language:linkable](https://w3id.org/p2p_ld/nwb-schema-language/linkable)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [Dataset](Dataset.md)
 * [Group](Group.md)
